# == Class: openbsd::mtree
#
# openpbsd::mtree applies mtree(8) with OpenBSD's (default) specifications.
# The default mount point is /module_data, which should be installed.
#
# The specs which are applied are
#
#   * 4.4BSD.dir
#   * BSD.local.dist
#   * BSD.x11.dist
#   * special
#
# Host specific files on the form <file>-${::fqdn} take precedence.
#
# === Parameters
#
# [*_mount*]
#   Meta parameter for specifying an alternate mount path.
#
# === Examples
#
#  class { 'openbsd::mtree':
#    $_mount = '/modules/openbsd',
#  }
#
#  include openbsd::mtree
#
class openbsd::mtree (
  $_mount = "/module_data/openbsd/${::operatingsystemrelease}/mtree",
) {
  define check (
    $path = $title,
    $file,
  ) {
    exec { "mtree ${title}":
      command => "/usr/sbin/mtree -qdef $file -p $path -u",
      logoutput => true,
      loglevel => 'info',
      returns => [0, 2],
      require => File[$file],
    } 
  }

  file { '/etc/mtree/4.4BSD.dist':
    ensure => file,
    owner => 'root',
    group => 'wheel',
    mode => '0444',
    source => [
      "puppet://${_mount}/4.4BSD.dist-${::fqdn}",
      "puppet://${_mount}/4.4BSD.dist",
    ],
  }

  file { '/etc/mtree/BSD.local.dist':
    ensure => file,
    owner => 'root',
    group => 'wheel',
    mode => '0444',
    source => [
      "puppet://${_mount}/BSD.local.dist-${::fqdn}",
      "puppet://${_mount}/BSD.local.dist",
    ],
  }

  file { '/etc/mtree/BSD.x11.dist':
    ensure => file,
    owner => 'root',
    group => 'wheel',
    mode => '0444',
    source => [
      "puppet://${_mount}/BSD.x11.dist-${::fqdn}",
      "puppet://${_mount}/BSD.x11.dist",
    ],
  }

  file { '/etc/mtree/special':
    ensure => file,
    owner => 'root',
    group => 'wheel',
    mode => '0600',
    source => [
      "puppet://${_mount}/special-${::fqdn}",
      "puppet://${_mount}/special",
    ],
  }

  check { '4.4BSD.dist':
    path => '/',
    file => '/etc/mtree/4.4BSD.dist',
  }

  check { 'BSD.local.dist':
    path => '/usr/local',
    file => '/etc/mtree/BSD.local.dist',
  }

  check { 'BSD.x11.dist':
    path => '/',
    file => '/etc/mtree/BSD.x11.dist',
  }

  check { 'special':
    path => '/',
    file => '/etc/mtree/special',
  }
}
